/**@addtogroup cstate
 * @{*/

/**@addtogroup cstate_ext  Interface
 * @{*/

/**@file
 * @brief C-State field definition (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project FIT - Fault Injection for TTA, IST-1999-10748
 */


#ifndef _FP1CSTAT_H
#define _FP1CSTAT_H

#include "ttpc/fl1debug.h"
#include "ttpc/fl1func.h"
#include "ttpc/fp1const.h"

/***********************************************************************************/

/** C-State field definition.*/
typedef struct {
	unsigned time;               /**< Time of next transmission (next action time) in macroticks.*/
	unsigned medl_position;      /**< Number of currently executed MEDL row.*/
	unsigned mode;               /**< Current operation mode number.*/
	unsigned dmc;		         /**< Pending deffered mode change.*/
	unsigned membership[MAX_SRU_COUNT];  /**< Membership vector for all active SRUs - @b 1 in this vector 
					       means, that the SRU sen a correct frame during last TDMA round.*/
} C_STATE; 

/***********************************************************************************/
/* Generated Access Functions */
/***********************************************************************************/

declare_access_functions(C_STATE, c_state, time);
declare_access_functions(C_STATE, c_state, medl_position);
declare_access_functions(C_STATE, c_state, mode);
declare_access_functions(C_STATE, c_state, dmc);
declare_index_access_functions(C_STATE, c_state, membership);

/***********************************************************************************/

/* Fills the argument with default fault mask for C-State. */
void c_state_fault_mask(unsigned* mask);

/** Calculate the CRC of whole @c C_STATE structure.*/
void c_state_chain_crc(C_STATE *c_state, unsigned *crc, unsigned polynomial, int length);

/** Compare two @c C_STATE structures and return nonzero code if they are identical.*/
unsigned c_state_cmp(C_STATE *cs1, C_STATE *cs2, int length);


#endif /* #ifndef _FP1CSTAT_H */

/*@}*/
/*@}*/

