/**@addtogroup lname
 * @{*/

/**@addtogroup lname_ext  Interface
 * @{*/
 

/**@file
 * @brief Controller's logical name definition and access functions
 *  (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748
 */

#ifndef _FP1LNAME_H
#define _FP1LNAME_H

#include "ttpc/fl1func.h"

/*************************************************************************************/

/** Defines the content of logical name of an SRU (part of CNI and MEDL).*/
typedef struct {
	unsigned multiplex_id;     /**< Additional identification for multiplexed 
				        nodes (0 for non-multiplexed).*/
	unsigned slot_position;    /**< Sending slot position within TDMA round (0-based).*/
	unsigned ps;		       /**< Flag that denotes a passive role for the SRU.*/
	unsigned _unused;          /**< Unused bits (5) reserved for later use.*/
} LOGICAL_NAME;


/*************************************************************************************/
/**@name Generated Access Functions
 * @{*/
declare_access_functions(LOGICAL_NAME, logical_name, ps);
declare_access_functions(LOGICAL_NAME, logical_name, slot_position);
declare_access_functions(LOGICAL_NAME, logical_name, multiplex_id);
/*@}*/
/*************************************************************************************/

/* Fill the argument with default fault mask. */
void logical_name_fault_mask(unsigned* mask);

/** Compare two logical name instances and return nonzero code if they are identical.*/
int logical_name_cmp(LOGICAL_NAME *lname1, LOGICAL_NAME *lname2);

/*************************************************************************************/

#endif /* #ifndef _FP1LNAME_H */

/*@}*/
/*@}*/

