/**@addtogroup medlrd
 * @{*/

/**@addtogroup medlrd_ext  Interface
 * @{*/


/**@file
 * @brief Provides a function that can read MEDL stored in a text file
 *  (interface).
 * @author Dan Trescak, Univerzity of West Bohemia, Czech Republic
 * @author Petr Grillinger, Univerzity of West Bohemia, Czech Republic
 * @version 1.5
 * @date Last modified 2002-11-16
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project FIT - Fault Injection for TTA, IST-1999-10748
 */

#ifndef _FP1MDLRD_H
#define _FP1MDLRD_H

#include "ttpc/fp1medl.h"

/*************************************************************************************/

/** Return codes of function \c read_medl_from_file().
When an error occurs while reading a line, the line number is stored
in an external variable called \c medl_read_error_line.
System errors store error code into external variable \c errno.*/
typedef enum {
	MEDL_READ_NO_ERROR = 0,       /**< Function completed successfuly - no error occured.*/
	MEDL_READ_INDEX_ERROR,        /**< File index is not in valid range.*/
	MEDL_READ_NULL_MEDL_ERROR,    /**< MEDL address is NULL pointer.*/
	MEDL_READ_FILE_OPEN_ERROR,    /**< File containing MEDL does not exist, see variable \c errno.*/
	MEDL_READ_FILE_READ_ERROR,    /**< Error reading from file, see variable \c errno.*/
	MEDL_READ_INVALID_ID_ERROR,   /**< Line does not contain a valid field identifier.*/
	MEDL_READ_UNKNOWN_TYPE_ERROR, /**< File contains field of unknown type - should never happen.*/
	MEDL_READ_UNKNOWN_ID_ERROR,   /**< File constains unknown field identifier.*/
	MEDL_READ_BAD_FEOF_ERROR      /**< Premature end of file - should never happen.*/
} MEDL_READ_ERROR_CODES;


/*************************************************************************************/

/** Number of the line where an error stopped execution.*/
extern int medl_read_error_line;


/*************************************************************************************/

/** Reads MEDL from a text file in the current directory - the file name is derived
	from the specified index and a predefined pattern.*/
MEDL_READ_ERROR_CODES medl_read_from_file(MEDL *medl, unsigned index);


/*************************************************************************************/
#endif

/*@}*/
/*@}*/

