/**@addtogroup misc_sim
 * @{*/

/**@addtogroup misc_sim_ext  Interface
 * @{*/


/**@file
 * @brief Various small and usefull functions and macros for the C-Sim library
 *  (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748
 */


#ifndef _SL1FUNC_H
#define _SL1FUNC_H

#include "csim/csim.h"

/************************************************************************************/

/** Check whether the process is planned by the C-Sim scheduler.*/
int process_is_planned(CSIM_PROCESS *process);

/** Check whether the process is currently active. */
int process_is_active(CSIM_PROCESS *process);

/** Check whether the process is terminated.*/
int process_is_terminated(CSIM_PROCESS *process);

/** Remove the process from C-Sim scheduler if the process is planned (must not be 
	active).*/
int process_cancel(CSIM_PROCESS *process);

/** Schedule the process execution to specified time (must not be active or terminated).*/
int process_activate_at(CSIM_PROCESS *process, CSIM_TIME time);

/** Schedule the process execution to tbegin after the specified delta time (must not 
	be active or terminated).*/
int process_activate_delay(CSIM_PROCESS *process, CSIM_TIME time);

/************************************************************************************/

#endif /* #ifndef SL1FUNC_H */

/*@}*/
/*@}*/

