/**@addtogroup bg_sim
 * @{*/

/**@addtogroup bg_sim_ext  Interface
 * @{*/

/**@file
 * @brief C-Sim simulation wrapper for local bus guardian (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748
 */

#ifndef _SP1BUSG_H
#define _SP1BUSG_H

#include "csim/csim.h"
#include "ttpc/fp1busg.h"

/*************************************************************************************/

struct bus_guardian_model;

/** C-Sim process that encapsulates the protocol defined internal state of BG
 * and simulation specific fields.*/
typedef struct bus_guardian_process {
	/**@name Inherited from C-Sim
	 * @{*/
	csim_d_process;
	/*@}*/
	BUS_GUARDIAN *protocol;            /**< Pointer to protocol defined state.*/
	struct bus_guardian_model *model;  /**< Pointer to simulation defined state.*/
} BUS_GUARDIAN_PROCESS;


/** Envelope for protocol specified fields and simulation data. */
typedef struct bus_guardian_model {
	/**@name Inherited Fields
	 * @{*/
	d_bus_guardian
	/*@}*/

	/**@name Simulation Specific Fields
	 * @{*/
	BUS_GUARDIAN_PROCESS  *process;  /**< Pointer to the C-Sim process that executes this BG.*/
	double clock_drift;              /**< Internal clock drift [sec/sec].*/
	/*@}*/
} BUS_GUARDIAN_MODEL;


/************************************************************************************/

/** Create and initialize a BUS_GUARDIAN process.*/
BUS_GUARDIAN_MODEL *bus_guardian_create(char *name);

/** Bind a controller to the bus guardian process.*/
void bus_guardian_attach_controller(BUS_GUARDIAN_MODEL *bg_model, void *controller);

/** Set the clock drift [sec/sec] for bus guardian.*/
void bus_guardian_set_clock_drift(BUS_GUARDIAN_MODEL *bg_model, double new_drift);

/************************************************************************************/

#endif /* #ifndef _SP1BUSG_H */

/*@}*/
/*@}*/

