/**@addtogroup chan_sim
 * @{*/

/**@addtogroup chan_sim_ext  Interface
 * @{*/


/**@file
 * @brief C-Sim simulation wrapper for transmission channel (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748
 */


#ifndef _SP1CHAN_H
#define _SP1CHAN_H

#include "csim/csim.h"
#include "ttpc/fp1chan.h"

/************************************************************************************/

struct channel_model;

/** C-Sim process that includes channel definition into its internal state.*/
typedef struct channel_process {
	/**@name Inherited from C-Sim
	 * @{*/
	csim_d_process;
	/*@}*/
	CHANNEL *protocol;               /**< Pointer to protocol defined fields.*/
	struct channel_model *model;     /**< Pointer to simulation defined fields.*/
} CHANNEL_PROCESS;


/** Internal state of channel enhanced with simulation oriented fields. */
typedef struct channel_model {
	/**@name Inherited Fields
	 * @{*/
	d_channel
	/*@}*/

	/**@name Simulation Specific Fields
	 * @{*/
	CHANNEL_PROCESS *process;   /**< Pointer to the C-Sim process that executes this channel.*/
	/*@}*/
} CHANNEL_MODEL;


/************************************************************************************/

/** Create and initialize a channel model - return pointer to the new instance.*/
CHANNEL_MODEL *channel_create(char *name);

/** Send a frame from the specified controller using the given channel.*/
int channel_send_frame(CHANNEL *channel, void *ctrl, PTR_CALLBACK callback);

/** Called by the sender to stop a send operation in progress.*/
void channel_cancel_send(CHANNEL *channel, void *ctrl);


/************************************************************************************/

#endif /* #ifndef _SP1CHAN_H */

/*@}*/
/*@}*/

