/**@addtogroup ldata_sim
 * @{*/

/**@addtogroup ldata_sim_ext  Interface 
 * @{*/


/**@file sp1ldata.h
 * @brief Simulation-specific controller's local data structure and access 
 *  functions (interface).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project FIT - Fault Injection for TTA, IST-1999-10748
 */


#ifndef _SP1LDATA_H
#define _SP1LDATA_H

#include "ttpc/fp1ldata.h"

/*************************************************************************************/

/** These constants describe exactly the current execution stat of the controller 
 * (inter-slot position).*/
typedef enum {
	CES_INIT = 0,         /**< Entering the init protocol state.*/
	CES_LISTEN_INIT,      /**< Entering the listen protocol state.*/
	CES_LISTEN_RESTART,   /**< Restarting the listen protocol state.*/
	CES_LISTEN_FINISH,    /**< Leaving the listen protocol state.*/
	CES_COLD_INIT,        /**< Entering the cold start protocol state.*/
	CES_COLD_PRP,         /**< Executing the PRP phase of cold start protocol state.*/
	CES_COLD_RESTART,     /**< Restarting the cold start protocol state.*/
	CES_COLD_FINISH,      /**< Leaving the cold start protocol state.*/
	CES_PRP,              /**< Executing the PRP phase of active protocol states.*/
	CES_PSP,              /**< Executing the PSP phase of active protocol states.*/
	CES_TP,               /**< Executing the TP phase of active protocol states.*/
	CES_IDLE              /**< Executing the idle IFG phase of active protocol states.*/
} CONTROLLER_EXE_STATE;


/** Simulation-specific (model) internal state of a controller.*/
typedef struct {
	CSIM_TIME action_time;            /**< Current action time (as in C-State) in model time units.*/
	CSIM_TIME clock_correction_time;  /**< Time of last clock correction in model time units.*/
	CSIM_TIME last_clock_access;      /**< Time of last cluster time (CNI field) update in model time units.*/
	double macrotick_frac;            /**< Fractional part of current cluster time in macroticks.*/
	CSIM_TIME tmp_model_time;         /**< Temporary storage field for model time.*/
	CSIM_TIME transmission_start[2];  /**< Last transmission start in model time units (for two channels).*/
	CSIM_TIME transmission_stop[2];   /**< Last transmission stop in model time units (for two channels).*/
	CONTROLLER_EXE_STATE exe_state;   /**< Current execution state of the controller (inter-slot position).*/
	int wake_on_co;                   /**< Flag that says whether the controller should wake up on @c co change.*/
	int wake_on_ca;                   /**< Flag that says whether the controller should wake up on @c ca change.*/
	int wake_on_receive;              /**< Flag that says whether the controller should wake up on reception of a frame.*/
} MLOC_DATA;


/** Initialize simulation-specific local data with default values.*/
MLOC_DATA *mloc_data_initialize(MLOC_DATA *ldata);

/*************************************************************************************/

#endif

/*@}*/
/*@}*/

