/**@file
 * @brief This is a documentation-only file for the Doxygen tool. There is no
 * code here that could be executed and the file is not compiled with the
 * project. 
 * @version 1.0
 * @date Last modified 2005-03-22 
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * 
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748 
 */


/**@mainpage
 *
 * This is the documentation generated automatically using Doxygen from a
 * C-Reference model of TTP/C.  The model was created within a project funded
 * by the the EC 5th framework programme called FIT (Fault Injection for TTA),
 * IST-1999-10748.
 *
 * The source codes documented here are separated into three basic groups which
 * you can find in the Modules section:
 * 	- Group \ref data contains standalone definitions of the
 * 	TTP/C specific data structures and methods to work with them.
 * 	- Group \ref act contains representations of all
 * 	active parts of a TTP/C node, like the communication controller.
 * 	- Group \ref misc contains all other modules that would
 * 	not fit cleanly into the data or activity groups.
 *
 * These three groups contain often subgroups of two types, which separate
 * different abstraction levels - functional description and simulation
 * framework:
 * 	- <em>Functional Description</em> or functional model does define the
 * 	behavior or structure of some part of TTP/C without using a specific
 * 	simulation tool or some platform dependant services.
 * 	- <em>Simulation Framework</em> then wraps the functionality provided
 * 	by the previously described module and adds timing and execution
 * 	capabilities supplied by a particular simulation tool (in our case
 * 	C-Sim).
 *
 * The individual source files are separated into a strict hierarchy defined
 * on the abstraction level and portability of the provided solution. The
 * position within this hierarchy is reflected by the file's name, namely by
 * the first two letters. We describe here only the five cases that can be
 * found in the TTP/C model, a full description is available elsewhere.
 * 	- @c fl1xxxxx  is a library providing general (not TTP/C specific)
 * 	functionality without the need of a simulator. 
 * 	- @c fp1xxxxx  is a functional description (model) of some part of
 * 	TTP/C that does not depend on a simulator.
 * 	- @c sl1xxxxx  is a simulation tool or library that provides functions
 * 	not linked to the TTP/C protocol.
 * 	- @c sp1xxxxx  is a simulation model of some part of the TTP/C
 * 	protocol. Mostly it is a wrapper around the corresponding @c fp1xxxxx
 * 	file.
 * 	- @c sa1xxxxx  is an application specific simulation model. In our
 * 	case, there is only a single module withing this category, the TTPOs
 * 	simulation model (@c sa1os).
 * 
 * \section  Copyright
 *
 * This work has been funded by EC project called FIT, IST-1999-10748. The
 * source codes have been developed by different people from the Czech
 * Technical University and University of West Bohemia - the particular 
 * authors are mentioned in the header of every file. The documentation was
 * prepared by Petr Grillinger as part of the PhD. Thesis called C-Reference
 * model of TTP/C.
 *
 * The source codes and this generated documentation are released under 
 * <em>The Academic Free Licence v. 2.1</em>, a licence certified by the 
 * Open Source Initiative (OSI).  
 *
 */


/****************************************************************************/

/**@addtogroup misc Miscellaneous
 * @brief All manner of modules that do not fit into the \ref data group or
 * \ref act group. 
 * 
 * @{*/
 
/**********************************/

/**@addtogroup debug Debugging and Logging Support
 *
 * This module provides buffered/unbuffered logging support. Separate reporting
 * levels can be enabled by preprocesor @c #define directives. This module also
 * replaces the standard @c assert macro with a version that correctly closes open
 * log files.
 */

/**********************************/

/**@addtogroup misc_func  Preprocessor Macros and General Purpose Routines
 * 
 * This module provides multiple small functions and macros that ease a
 * programmers everyday's work.
 * 
 * @attention Extra attention should be paid to a group of macros that were
 * used to create function headers as well as simle function definitions. You
 * will encounter them in almost every file from the protocol layer and without
 * knowing how they work, they can be quite confusing.
 */

/**********************************/

/**@addtogroup medlrd  Reading of MEDL files
 *
 * This module provides routines that are able to extract a MEDL table from an
 * ASCII file in given format. The table is then written inside a new #MEDL
 * structure in memory and can be used by the controller model.
 */

/**********************************/

/**@addtogroup os  Operating System Simulation
 *  
 * This is a model of a real-time operating system for the TTP/C simulation
 * model.  It is relies on the C-Sim tool as means of process and time
 * management.
 *
 * @note This model does not fullfil the TTPOs specification. Its interface was
 * designed to allow users to write small and portable applications.
 */

/**********************************/

/**@addtogroup misc_sim  C-Sim Extensions
 *
 * This module provides various functions that complement the C-Sim simulation
 * library or work around some of its problems.
 * @{*/

/**********************************/

/*@}*/

/****************************************************************************/

/**@addtogroup act Activity Models
 * Here are all modules that represent some activity model of TTP/C, like the
 * communication controller or bus guarian for example.
 * @{*/

/**********************************/

/**@addtogroup chan Bus Channel
 * This is a very simple model of a broadcast channel in a bus network topology.
 * @{*/

/**@addtogroup chan_fun Bus Channel Model
 *
 * This module provides basic functionality of a single transmission channel.
 * So far only a bus implementation is available.  Time relations are defined
 * in the @ref chan_sim module.
 */

/**@addtogroup chan_sim  Bus Channel Simulation
 * 
 * This module binds the channel model defined in the \ref chan_fun module into
 * a C-Sim process and thus provides an executable model of transmission
 * channel.
 */

/*@}*/

/**********************************/

/**@addtogroup bg Bus Guardian
 * A bus guardian is a unit that limits the transmissions of the
 * communication controller to a specific time window. This is the model of a
 * local bus guardian which is integrated into the modelled version of TTP/C
 * nodes.
 * @{*/

/**@addtogroup bg_fun Bus Guardian Model
 *
 * This module provides basic functionality of the Bus Guardian (BG) unit.
 */

/**@addtogroup bg_sim  Bus Guardian Simulation 
 *
 * This module binds the BG model defined in the \ref bg_fun module into a
 * C-Sim process and thus provides an executable model of BG.
 */

/*@}*/

/**********************************/

/**@addtogroup ctrl Communication Controller
 * A communication controller in TTP/C node performs the actual message
 * transmission based on a time triggered schedule stored within a MEDL table.
 * The controller communicates with a host computer through the CNI interface.
 * @{*/

/**@addtogroup ctrl_fun Controller Controller Model
 * 
 * This module provides the functionality of a TTP/C Communication Controller.
 * It defines a large number of functions can be used to form the state-machine
 * of the ctrl, but not the state-machine itself. This task requires the notion
 * of time that is not provided at this level and is introduced in module @ref
 * ctrl_sim
 */

/**@addtogroup ctrl_sim  Communication Controller Simulation
 * 
 * This module binds the functionality and data structures provided by
 * protocol-level implementation of communication ctrl with C-Sim simulation
 * library and provides an executable C-Sim proccess that simulates the ctrl.
 */

/*@}*/

/**********************************/

/*@}*/

/****************************************************************************/

/**@addtogroup data  Data Structures
 * This group presents all stand-alone (or very large and important) memory
 * structures used within a TTP/C node. There is no activity associated with
 * these data, but access functions are provided.
 * @{*/

/**********************************/

/**@addtogroup cstate  C-State
 *
 * C-State contains the global cluster state for the particular transmission
 * round, slot, and operating mode combination. All nodes must agree on the
 * C-State value to guarantee synchronized operation.
 */

/**********************************/

/**@addtogroup frame  TTP/C Frames
 * 
 * This modules defines two basic types of frames - I-frame and N-frame and
 * several access functions. Moreover it provides a union that encapsulates
 * both frame types into one object.
 */

/**********************************/

/**@addtogroup lname  Logical Name
 *
 * A logical name completely identifies a sender in TTP/C cluster. The
 * information in this structure defines the sending slot within a TDMA round
 * (every node can have only one). If the node shares the slot with other nodes
 * (multiplexed SRU slot), a unique ID among these nodes is also used.
 */

/**********************************/

/**@addtogroup medl  Message Descriptor List (MEDL)
 *
 * A message descriptor list contains a complete configuration for the
 * communication controller. This includes implementation specific parameters
 * regarding transmission speed, various timeouts, and most importantly the
 * transmission schedule for all messages.
 */

/**********************************/

/**@addtogroup cni  Communication Network Interface (CNI)
 * The Communication Network Interace (CNI) is perhaps the most important
 * structure in the model. It is used as the only means of communication
 * between host and communication controller. Its special property is that it
 * prohibits the propagation of temporal faults since no timing information is
 * transferred across this structure. 
 * @{*/

/**@addtogroup cni_fun  CNI Model
 * 
 * This module defines the Communication Network Interface (CNI). It provides
 * the actual structure together with a complete set of access functions.  Time
 * relations are not introduced in this module, this is solved by the @ref
 * cni_sim module
 */

/**@addtogroup cni_sim  CNI Simulation
 * This particular implementation does not update some of the CNI fields
 * periodically as specified, but implementes instead on-demand value
 * producing. This is done for the current global time field mainly and
 * requires access to the simulation framework. 
 */

/*@}*/

/**********************************/

/**@addtogroup ldata  Controller's Local Data
 * The communication controller requires several registers (or memory cells) to
 * store its state. Some of the state information is explitly mentioned in the
 * specification by not all. We felt that making all state explicit in a well
 * defined data structure would help to analyze the TTP/C.
 * 
 * @{*/

/**@addtogroup ldata_fun  Controller's Local Data Model
 * 
 * This module provides a structure that encapsulates the internal data stored
 * within a controller. It only handles data required by the protocol level.
 * Basic functions for access to individual fields are provided.
 */

/**@addtogroup ldata_sim  Controller's Local Data Simulation
 *
 * This module provides a structure that encapsulates the internal data
 * required for controller model. It only handles data required by the
 * simulation layer.
 */

/*@}*/

/**********************************/

/*@}*/

/****************************************************************************/

