/**@addtogroup misc_func
 * @{*/

/**@addtogroup misc_func_int  Implementation
 * @{*/

/**@file
 * @brief Various small and usefull functions and macros (implementation).
 * @version 1.5
 * @date Last modified 2002-11-16 
 * @author Petr Grillinger, Univerzity of West Bohemia, Czech Republic
 * @author Jan Jezek, Univerzity of West Bohemia, Czech Republic
 * 
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project @b FIT - Fault Injection for TTA, IST-1999-10748 */


#include <math.h>

#include "ttpc/fl1func.h"


/*************************************************************************************/
/* Exported Functions */
/*************************************************************************************/

/* Performs continous calculation of 16-bit CRC code using the provided buffer.
 *
 * The function may be used to calculate CRC from data of any size. Individial
 * items of the data are feeded sequentialy into this function. The size of
 * inidividual data items can be up to 32 bits. Before a new CRC is calculated,
 * the content of @a crc variable should be initialized.
 * 
 * @param crc A user allocated buffer, where the CRC is stored. It must be
 *  initialized or contain an older CRC value.
 * @param polynomial The polynomial used for CRC calculations.
 * @param data A piece of data to be included into the CRC code.
 * @param bits Number of bits to be taken from the @a data argument.
 * @return The current value of CRC; the same as the content of @a crc
 *  argument.
 *
 * @todo Optimize using a byte table*/
unsigned get_crc(unsigned *crc, unsigned polynomial, unsigned data, unsigned bits)
{
	unsigned t = *crc;

	while (bits > 0) {
		t = ((t << 1) & bit_mask(16)) ^ ((t >> 15) ^ (data & 1) ? polynomial & bit_mask(16) : 0);
		bits--;
		data >>= 1;
	}

	*crc = t;
	return t;
}


/* Returns the fractional part of a floating point number.
 *
 * @param x A floating point number.
 * @return The fractional part of @a x.*/
double fract(double x)
{
	double i;

	return modf(x, &i);
}

/*************************************************************************************/

/*@}*/
/*@}*/

