/**@addtogroup ldata_fun
 * @{*/

/**@addtogroup ldata_fun_int  Implementation
 * @{*/


/**@file
 * @brief Protocol defined controller's local data structure and access 
 *  functions (implementation).
 * @version 1.5
 * @date Last modified 2002-11-16 
 * @author Petr Grillinger, Univerzity of West Bohemia, Czech Republic
 * @author Jan Jezek, Univerzity of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 * created as part of EU project \b FIT - Fault Injection for TTA, IST-1999-10748
 */


#include <string.h>

#include "ttpc/fp1ldata.h"
#include "ttpc/fp1frame.h"


/************************************************************************************/
/* Exported Functions */
/************************************************************************************/

/**.
 *
 * @param ldata Pointer to controller's local data.
 * @return Pointer to the initialized structure (content of the \a ldata argument).*/
PLOC_DATA *ploc_data_initialize(PLOC_DATA *ldata)
{
	memset(&ldata->frame[0], 0, sizeof(FRAME));
	memset(&ldata->frame[1], 0, sizeof(FRAME));
	ldata->old_ccf = 0;
	ldata->old_msg_ccf[0] = ldata->old_msg_ccf[1] = 0;
	ldata->protocol_state = PS_FREEZE;
	ldata->iack_state = IACK_OK;
	ldata->successor = 0;
	ldata->membership_pos = 0;
	memset(ldata->sync_stack, 0, sizeof(ldata->sync_stack));
	ldata->sync_stack_top = 0;
	ldata->tp_sync_interrupt = 0;
	ldata->mtd_a = 0;
	ldata->mtd_b = 0;
	ldata->psp_phase = 0;
	ldata->immediate_send_permission = 0;
	ldata->sync_period_params = 0;

	ldata->csct = 0;
	memset(&ldata->logical_name, 0, sizeof(ldata->logical_name));

	return ldata;
}


/**.
 *
 * The function stores the given value into the push-down stack within local data.
 * Afterwards it increments the sync_stack_top pointer modulo stack size.
 *
 * @param ldata Pointer to controller's local data.
 * @param value Time difference in microticks tha will be stored into the stack.
 * @return The pushed value.*/
int ploc_data_push_sync_stack(PLOC_DATA *ldata, int value)
{
	ldata->sync_stack[ldata->sync_stack_top] = value;
	ldata->sync_stack_top = (ldata->sync_stack_top + 1)	% SYNC_STACK_SIZE;
	return value;
}

/************************************************************************************/

/*@}*/
/*@}*/

