/**@addtogroup lname
 * @{*/

/**@addtogroup lname_int  Implementation
 * @{*/


/**@file
 * @brief Controller's logical name definition and access functions
 *  (implementation).
 * @version 1.5
 * @date Last modified 2002-11-16
 * @author Petr Grillinger, Univerzity of West Bohemia, Czech Republic
 * @author Jan Jezek, Univerzity of West Bohemia, Czech Republic
 * 
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project FIT - Fault Injection for TTA, IST-1999-10748
 */

#include "ttpc/fl1debug.h"
#include "ttpc/fp1lname.h"
#include "ttpc/fl1func.h"
#include <string.h>

/*************************************************************************************/
/* Generated Access Functions */
/*************************************************************************************/
implement_access_functions(LOGICAL_NAME, logical_name, ps, 1)
implement_access_functions(LOGICAL_NAME, logical_name, slot_position, 6)
implement_access_functions(LOGICAL_NAME, logical_name, multiplex_id, 4)

/*************************************************************************************/
/* Exported Functions */
/*************************************************************************************/

/* Fill the argument with default fault mask. */
void logical_name_fault_mask(unsigned* mask)
{
    LOGICAL_NAME *p = (LOGICAL_NAME*)mask;
    memset(p, 0, sizeof(LOGICAL_NAME));

    p->ps = 1;
	p->slot_position = bit_mask(6);
	p->multiplex_id = bit_mask(4);
	p->_unused = bit_mask(5);
}
    
/**.
 *
 * This function compares field by field the contents of two logical names. Only used fields
 * are compared. i.e. not reserved fields.
 * 
 * @param lname1 Pointer to the first instance of logical name.
 * @param lname2 Pointer to the second instance of logical name.
 * @return Nonzero code if both logical names are identical, zero code otherwise.*/
int logical_name_cmp(LOGICAL_NAME *lname1, LOGICAL_NAME *lname2)
{
	return (logical_name_get_ps(lname1) == logical_name_get_ps(lname2))
		&& (logical_name_get_slot_position(lname1) == logical_name_get_slot_position(lname2))
		&& (logical_name_get_multiplex_id(lname1) == logical_name_get_multiplex_id(lname2));
}

/*************************************************************************************/

/*@}*/
/*@}*/

