/**@addtogroup medl
 * @{*/

/**@addtogroup medl_int  Implementation
 * @{*/

/**@file
 * @brief Defines the MEDL structure and access functions (implementation).
 * @author Petr Grillinger, Univerzity of West Bohemia, Czech Republic
 * @author Jan Jezek, Univerzity of West Bohemia, Czech Republic
 * @version 1.5
 * @date Last modified 2002-11-16
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project \b FIT - Fault Injection for TTA, IST-1999-10748
 */

#include <stdlib.h>

#include "ttpc/fp1medl.h"
#include "ttpc/fl1func.h"

/************************************************************************************/

/**\name Generated Access Functions for MEDL_CCP
Access functions for \c MEDL_CCP structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_CCP, medl_ccp, physical_sru_name, 8)
implement_access_functions(MEDL_CCP, medl_ccp, controller_version, 8)
implement_access_functions(MEDL_CCP, medl_ccp, app_id, 8)
implement_access_functions(MEDL_CCP, medl_ccp, app_version, 8)
implement_access_functions(MEDL_CCP, medl_ccp, cf, 1)
implement_access_functions(MEDL_CCP, medl_ccp, c_state_length, 4)
implement_access_functions(MEDL_CCP, medl_ccp, tdma_round_length, 15)
implement_access_functions(MEDL_CCP, medl_ccp, startup_timeout, 16)
implement_access_functions(MEDL_CCP, medl_ccp, free_running_macroticks, 16)
implement_access_functions(MEDL_CCP, medl_ccp, mmfc, 8)
implement_access_functions(MEDL_CCP, medl_ccp, microtick_int, 8)
implement_access_functions(MEDL_CCP, medl_ccp, microtick_frac, 16)
implement_access_functions(MEDL_CCP, medl_ccp, max_cold_start_entry, 8)
implement_access_functions(MEDL_CCP, medl_ccp, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_BGP
Access functions for \c MEDL_BGP structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_BGP, medl_bgp, bg_arm_phase, 16)
implement_access_functions(MEDL_BGP, medl_bgp, bg_slot_offset, 16)
implement_access_functions(MEDL_BGP, medl_bgp, bg_slot_duration, 16)
implement_access_functions(MEDL_BGP, medl_bgp, bg_remaining_round, 16)
implement_access_functions(MEDL_BGP, medl_bgp, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_RL
Access functions for \c MEDL_RL structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_RL, medl_rl, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_MCE
Access functions for \c MEDL_MCE structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_index_access_functions(MEDL_MCE, medl_mce, deferred_mode, 5)
implement_access_functions(MEDL_MCE, medl_mce, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_ISP
Access functions for \c MEDL_ISP structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_ISP, medl_isp, entries, 10)
implement_access_functions(MEDL_ISP, medl_isp, rom_speed, 4)
implement_access_functions(MEDL_ISP, medl_isp, i_frame_time, 16)
implement_access_functions(MEDL_ISP, medl_isp, ifg_time, 16)
implement_access_functions(MEDL_ISP, medl_isp, listen_delay, 16)
implement_access_functions(MEDL_ISP, medl_isp, watchdog_slot_length, 16)
implement_access_functions(MEDL_ISP, medl_isp, listen_timeout_extension, 8)
implement_access_functions(MEDL_ISP, medl_isp, listen_timeout_restart_time, 8)
implement_access_functions(MEDL_ISP, medl_isp, oversampling_rate, 8)
implement_access_functions(MEDL_ISP, medl_isp, sync_interval, 8)
implement_access_functions(MEDL_ISP, medl_isp, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_SCE
Access functions for \c MEDL_SCE structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_SCE, medl_sce, sru_slot_duration, 16)
implement_access_functions(MEDL_SCE, medl_sce, mo, 1)
implement_access_functions(MEDL_SCE, medl_sce, membership_pos, 6)
implement_access_functions(MEDL_SCE, medl_sce, medl_pos, 9)
implement_access_functions(MEDL_SCE, medl_sce, mm, 1)
implement_access_functions(MEDL_SCE, medl_sce, eor, 1)
implement_access_functions(MEDL_SCE, medl_sce, ra, 1)
implement_access_functions(MEDL_SCE, medl_sce, eot, 1)
implement_access_functions(MEDL_SCE, medl_sce, cs, 1)
implement_access_functions(MEDL_SCE, medl_sce, syf, 1)
implement_access_functions(MEDL_SCE, medl_sce, ba, 1)
implement_access_functions(MEDL_SCE, medl_sce, delay_correction, 6)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL_MAE
Access functions for \c MEDL_MAE structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL_MAE, medl_mae, ru1, 1)
implement_access_functions(MEDL_MAE, medl_mae, ia, 1)
implement_access_functions(MEDL_MAE, medl_mae, cni_address_cha, 14)
implement_access_functions(MEDL_MAE, medl_mae, ru2, 1)
implement_access_functions(MEDL_MAE, medl_mae, ib, 1)
implement_access_functions(MEDL_MAE, medl_mae, cni_address_chb, 14)
implement_index_access_functions(MEDL_MAE, medl_mae, mcp_i, 1)
implement_index_access_functions(MEDL_MAE, medl_mae, mcp_d, 1)
implement_access_functions(MEDL_MAE, medl_mae, mcp_c, 1)
implement_access_functions(MEDL_MAE, medl_mae, eoc, 1)
implement_access_functions(MEDL_MAE, medl_mae, dafla, 4)
implement_access_functions(MEDL_MAE, medl_mae, daflb, 4)
implement_access_functions(MEDL_MAE, medl_mae, crc, 16)
/*\}*/

/************************************************************************************/

/**\name Generated Access Functions for MEDL
Access functions for \c MEDL structure that were generated by preprocessor macros.
All of these functions access the structure passed to them in the \a _structure
argument and either write a new value (\a _value argument) or return the current
content of a particular field. For access to vectors an index must be also passed
unsign the \a _index argument.
\see implement_access_functions, get_function_body, set_function_body, increment_function_body*/
/*\{*/
implement_access_functions(MEDL, medl, revision, 16)
/*\}*/
/************************************************************************************/

/************************************************************************************/
/**\name Exported Functions*/
/*\{*/

/**.
\param medl_ccp Pointer to a MEDL_CCP part of MEDL.
\return A floating point value that is composed from the itegral and fractional parts
	of microtick per macrotick field stored in MEDL.*/
double medl_ccp_get_microticks(MEDL_CCP *medl_ccp)
{
	return medl_ccp->microtick_int +
		(double)medl_ccp->microtick_frac / (1 << 16);
}


/**.
\param medl Pointer to an instance of MEDL.
\return Nonzero code if the CRC check is passed, zero otherwise.
\todo No CRC check is performed - the function is hardwired to return successfully.*/
int medl_validity_check(MEDL *medl)
{
	return (medl != NULL);
}

/*\}*/
/************************************************************************************/

/*@}*/
/*@}*/

