/**@addtogroup ldata_sim
 * @{*/

/**@addtogroup ldata_sim_int  Implementation
 * @{*/


/**@file
 * @brief Simulation-specific controller's local data structure and access
 *  functions (implementation).
 * @version 1.5
 * @date Last modified 2002-11-16 
 * @author Petr Grillinger, University of West Bohemia, Czech Republic
 * @author Jan Jezek, University of West Bohemia, Czech Republic
 *
 * @note This file is part of C-Sim model of TTP/C protocol 0.1, 
 *  created as part of EU project \b FIT - Fault Injection for TTA, IST-1999-10748
 */


#include "csim/csim.h"
#include "ttpc/sp1ldata.h"


/************************************************************************************/
/* Exported Fucntions */
/************************************************************************************/

/**.
 * 
 * @param ldata Pointer to an instance ld @c MLOC_DATA or derived structure.
 * @return Pointer to the initialized structure (the same as @a ldata argument).*/
MLOC_DATA *mloc_data_initialize(MLOC_DATA *ldata)
{
	ldata->action_time = 0.0;
	ldata->clock_correction_time = csim_time();
	ldata->last_clock_access = csim_time();
	ldata->macrotick_frac = 0.0;
	ldata->tmp_model_time = 0.0;
	ldata->transmission_start[0] = 0.0;
	ldata->transmission_start[1] = 0.0;
	ldata->transmission_stop[0] = 0.0;
	ldata->transmission_stop[1] = 0.0;
	ldata->exe_state = CES_INIT;
	ldata->wake_on_co = 1;
	ldata->wake_on_ca = 1;
	ldata->wake_on_receive = 0;

	return ldata;
}

/************************************************************************************/

/*@}*/
/*@}*/

